@@ -38,14 +38,13 @@ public:
 	CommunicationSpinBox();
 	~CommunicationSpinBox();
 	
-signals:
+Q_SIGNALS:
 	int valueChanged(int newValue);
 	
-public slots:
+public Q_SLOTS:
 	void increaseValue();
 };
 
-
 class LockUnlock{
 public:
 	static void computeLockedUnlockedActivitiesTimeSpace();
